Imports MultiServing.ProfileManager.Helpers

Namespace MultiServing.ProfileManager.Core
	Public Class DefaultDeviceProfiler
		Implements IDeviceProfiler

		Public Overridable ReadOnly Property MobileSuffix As String Implements IDeviceProfiler.MobileSuffix
			Get
				Return "mobile"
			End Get
		End Property

		Public Overridable Function IsMobile(ByVal userAgent As String) As Boolean Implements IDeviceProfiler.IsMobile
			Return HasAnyMobileKeywords(userAgent)
		End Function

		Public Overridable ReadOnly Property SmartphoneSuffix As String Implements IDeviceProfiler.SmartphoneSuffix
			Get
				Return "smartphone"
			End Get
		End Property

		Public Overridable Function IsSmartphone(ByVal userAgent As String) As Boolean Implements IDeviceProfiler.IsSmartphone
			Return IsMobile(userAgent)
		End Function

		Public Overridable ReadOnly Property TabletSuffix As String Implements IDeviceProfiler.TabletSuffix
			Get
				Return "tablet"
			End Get
		End Property

		Public Overridable Function IsTablet(ByVal userAgent As String) As Boolean Implements IDeviceProfiler.IsTablet
			Return IsMobile(userAgent) AndAlso userAgent.ContainsAny("tablet", "ipad")
		End Function

		Public Overridable Function IsDesktop(ByVal userAgent As String) As Boolean Implements IDeviceProfiler.IsDesktop
			Return HasAnyDesktopKeywords(userAgent)
		End Function

		#Region "Private members"
		Private Function HasAnyMobileKeywords(ByVal userAgent As String) As Boolean
			Dim ua = userAgent.ToLower
			Return (ua.Contains("midp") OrElse ua.Contains("mobile") OrElse ua.Contains("android") OrElse ua.Contains("samsung") OrElse ua.Contains("nokia") OrElse ua.Contains("phone") OrElse ua.Contains("opera mini") OrElse ua.Contains("opera mobi") OrElse ua.Contains("sonyericsson") OrElse ua.Contains("blackberry") OrElse ua.Contains("symbian") OrElse ua.Contains("j2me") OrElse ua.Contains("windows ce") OrElse ua.Contains("vodafone") OrElse ua.Contains("ipad;") OrElse ua.Contains("palm") OrElse ua.Contains("fennec") OrElse ua.Contains("wireless") OrElse ua.Contains("htc") OrElse ua.Contains("nintendo") OrElse ua.Contains("zunewp7") OrElse ua.Contains("silk"))
		End Function

		Private Shared Function HasAnyDesktopKeywords(ByVal userAgent As String) As Boolean
			Dim ua = userAgent.ToLower
			Return ua.Contains("wow64") OrElse ua.Contains(".net clr") OrElse ua.Contains("gtb6") OrElse ua.Contains("gtb7") OrElse ua.Contains("gtb8") OrElse ua.Contains("macintosh") OrElse ua.Contains("slcc1") OrElse ua.Contains("aol 9.") ' related to Windows Vista -  Google toolbar
		End Function
		#End Region

	End Class
End Namespace
