Imports System.IO
Imports System.Web.Mvc
Imports MultiServing.ProfileManager.Core

Namespace MultiServing.ProfileManager.Mvc
	Public Class MobileRazorViewEngine
		Inherits RazorViewEngine

		Protected Overrides Function CreatePartialView(ByVal controllerContext As ControllerContext, ByVal partialPath As String) As IView
			Dim mobilePath = partialPath
			If Not String.IsNullOrEmpty(partialPath) Then
				mobilePath = GetMobileViewName(controllerContext.HttpContext.Request, partialPath)
			End If
			Return MyBase.CreatePartialView(controllerContext, mobilePath)
		End Function

		Protected Overrides Function CreateView(ByVal controllerContext As ControllerContext, ByVal viewPath As String, ByVal masterPath As String) As IView
			Dim mobileView = viewPath
			Dim mobileMaster = masterPath

			If Not String.IsNullOrEmpty(viewPath) Then
				mobileView = GetMobileViewName(controllerContext.HttpContext.Request, viewPath)
			End If
			If Not String.IsNullOrEmpty(masterPath) Then
				mobileMaster = GetMobileViewName(controllerContext.HttpContext.Request, masterPath)
			End If
			Return MyBase.CreateView(controllerContext, mobileView, mobileMaster)
		End Function

		Public Shared Function GetMobileViewName(ByVal request As HttpRequestBase, ByVal path As String) As String
			Dim profiler = If(TryCast(DependencyResolver.Current.GetService(GetType(IDeviceProfiler)), IDeviceProfiler), New DefaultDeviceProfiler)

			Dim ua = If(request.UserAgent, String.Empty)
			Dim suffix = GetSuffix(ua, profiler)
            Dim extension = String.Format("{0}{1}", suffix, System.IO.Path.GetExtension(path))
            Return System.IO.Path.ChangeExtension(path, extension)
		End Function

		Private Shared Function GetSuffix(ByVal ua As String, ByVal profiler As IDeviceProfiler) As String
			If profiler.IsDesktop(ua) Then
				Return String.Empty
			End If

			If profiler.IsSmartphone(ua) Then
				Return profiler.SmartphoneSuffix
			End If
			If profiler.IsTablet(ua) Then
				Return profiler.TabletSuffix
			End If
			Return If(profiler.IsMobile(ua), profiler.MobileSuffix, String.Empty)
		End Function
	End Class
End Namespace
