Imports MultiServing.ProfileManager.Helpers
Imports WURFL

Namespace MultiServing.Framework.Wurfl
	Public Module DeviceExtensions
		''' <summary>
		''' Indicates whether the browser behind the current request is wireless
		''' </summary>
		''' <param name="device">WURFL device</param>
		''' <returns>True if it's a mobile device, false otherwise</returns>
		<System.Runtime.CompilerServices.Extension>
		Public Function IsWireless(ByVal device As IDevice) As Boolean
			Return device.GetCapability("is_wireless_device").ToBool
		End Function

		''' <summary>
		''' Indicates whether the requesting device is a tablet
		''' </summary>
		''' <param name="device">WURFL device</param>
		''' <returns>True if it's a tablet device, false otherwise</returns>
		<System.Runtime.CompilerServices.Extension>
		Public Function IsTablet(ByVal device As IDevice) As Boolean
			Return device.GetCapability("is_tablet").ToBool
		End Function

		''' <summary>
		''' Indicates whether the browser behind the current request has touch capabilities
		''' </summary>
		''' <param name="device">WURFL device</param>
		''' <returns>True if it's a mobile device, false otherwise</returns>
		<System.Runtime.CompilerServices.Extension>
		Public Function IsTouch(ByVal device As IDevice) As Boolean
			Return device.GetCapability("pointing_method").Equals("touchscreen")
		End Function

		''' <summary>
		''' Gets width of the device in pixels
		''' </summary>
		''' <param name="device">WURFL device</param>
		''' <returns>True if it's a mobile device, false otherwise</returns>
		<System.Runtime.CompilerServices.Extension>
		Public Function Width(ByVal device As IDevice) As Int32
			Return device.GetCapability("resolution_width").ToInt
		End Function

		''' <summary>
		''' Gets the OS of the device (if any)
		''' </summary>
		''' <param name="device">WURFL device</param>
		''' <returns>Name of the OS, if any</returns>
		<System.Runtime.CompilerServices.Extension>
		Public Function Os(ByVal device As IDevice) As String
			Dim deviceOs = device.GetCapability("device_os")
			Dim deviceOsVersion = device.GetCapability("device_os_version")
			Return String.Format("{0} {1}", deviceOs, deviceOsVersion).Trim
		End Function

		''' <summary>
		''' Indicates whether the device runs the specified OS (version)   
		''' </summary>
		''' <param name="device">WURFL device</param>
		''' <param name="os">Name of the OS</param>
		''' <returns>True if it's a mobile device, false otherwise</returns>
		<System.Runtime.CompilerServices.Extension>
		Public Function HasOs(ByVal device As IDevice, ByVal os As String) As Boolean
			Return HasOs(device, os, New Version(0, 0))
		End Function

		<System.Runtime.CompilerServices.Extension>
		Public Function HasOs(ByVal device As IDevice, ByVal os As String, ByVal version As Version) As Boolean
			' Check OS
			Dim deviceOs = device.GetCapability("device_os")
			If Not deviceOs.Equals(os, StringComparison.InvariantCultureIgnoreCase) Then
				Return False
			End If

			' Check OS version
			Dim deviceOsVersion = device.GetCapability("device_os_version")
			If Not deviceOsVersion.Contains(".") Then
				deviceOsVersion = String.Format("{0}.0", deviceOsVersion)
			End If

            Dim detectedVersion As Version = Nothing
			Dim success = Version.TryParse(deviceOsVersion, detectedVersion)
			If Not success Then
				Return False
			End If
			Return detectedVersion.CompareTo(version) >= 0
		End Function

		<System.Runtime.CompilerServices.Extension>
		Public Function HasOs(ByVal device As IDevice, ByVal os As String, ByVal version As String) As Boolean
			' Check OS
			Dim deviceOs = device.GetCapability("device_os")
			If Not deviceOs.Equals(os, StringComparison.InvariantCultureIgnoreCase) Then
				Return False
			End If

			' Check OS version
			Dim deviceOsVersion = device.GetCapability("device_os_version")
			Return deviceOsVersion.Equals(version, StringComparison.InvariantCultureIgnoreCase)
		End Function
	End Module
End Namespace
